@@ -2,15 +2,15 @@
 #' @export
 print.datapackage <- function(x, properties = NA, ...) {
   printdescription(x)
-  cat("\nLocation: <", attr(x, "path"), ">", sep="")
+  cat("\n", c2("Location"), ": <", attr(x, "path"), ">", sep="")
   if (dp_nresources(x) > 0) {
-    cat("\nResources:\n")
+    cat("\n\n", c2("Resources"), ":\n", sep = "")
     resources <- dp_resource_names(x)
     for (resource in resources) {
-      printdescription(dp_resource(x, resource), description = FALSE)
+      print(dp_resource(x, resource), tiny = TRUE)
     }
   } else {
-    cat("\n<NO RESOURCES>\n")
+    cat(bd(c1("\n<NO RESOURCES>\n")))
   }
   attributes <- dp_properties(x)
   if (length(properties) == 1 && is.na(properties)) properties <- attributes
@@ -19,7 +19,7 @@ print.datapackage <- function(x, properties = NA, ...) {
   if (length(toprint)) {
     tmp <- lapply(toprint, \(property) dp_property(x, property))
     names(tmp) <- toprint
-    cat("\nSelected properties:\n")
+    cat("\n", c2("Selected properties"), ":\n", sep = "")
     utils::str(tmp, max.level=1, give.attr=FALSE, no.list = TRUE, 
       comp.str="", indent.str="", give.head = FALSE)
   }
